@@ -3,11 +3,11 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 import logging
 import os
 import signal
 import sys
-import contextlib
 from contextlib import asynccontextmanager
 from typing import TYPE_CHECKING, Any
 
@@ -25,9 +25,13 @@ __all__ = ["MCPServer"]
 
 logger = logging.getLogger(__name__)
 
+# Global flag to track if shutdown was triggered by SIGTERM
+_sigterm_received = False
+
 
 def _run_with_sigterm(coro_fn: Callable[..., Any], *args: Any, **kwargs: Any) -> None:
     """Run *coro_fn* via anyio.run() and cancel on SIGTERM or SIGINT (POSIX)."""
+    global _sigterm_received
 
     async def _runner() -> None:
         stop_evt: asyncio.Event | None = None
@@ -35,9 +39,16 @@ def _run_with_sigterm(coro_fn: Callable[..., Any], *args: Any, **kwargs: Any) ->
             loop = asyncio.get_running_loop()
             stop_evt = asyncio.Event()
 
+            # Handle SIGTERM for production shutdown
+            def handle_sigterm() -> None:
+                global _sigterm_received
+                _sigterm_received = True
+                logger.info("Received SIGTERM signal")
+                stop_evt.set()
+
             # Handle both SIGTERM and SIGINT for graceful shutdown
             if signal.getsignal(signal.SIGTERM) is signal.SIG_DFL:
-                loop.add_signal_handler(signal.SIGTERM, stop_evt.set)
+                loop.add_signal_handler(signal.SIGTERM, handle_sigterm)
             if signal.getsignal(signal.SIGINT) is signal.SIG_DFL:
                 loop.add_signal_handler(signal.SIGINT, stop_evt.set)
 
@@ -62,6 +73,7 @@ class MCPServer(FastMCP):
     """FastMCP wrapper that adds helpful functionality for dockerized environments.
     This works with any MCP client, and adds just a few extra server-side features:
     1. SIGTERM handling for graceful shutdown in container runtimes.
+       Note: SIGINT (Ctrl+C) is not handled, allowing normal hot reload behavior.
     2. ``@MCPServer.initialize`` decorator that registers an async initializer
        executed during the MCP *initialize* request. The initializer function receives
        a single ``ctx`` parameter (RequestContext) from which you can access:
@@ -69,7 +81,7 @@ class MCPServer(FastMCP):
        - ``ctx.meta.progressToken``: Token for progress notifications (if provided)
        - ``ctx.session.client_params.clientInfo``: Client information
     3. ``@MCPServer.shutdown`` decorator that registers a coroutine to run during
-       server teardown, after all lifespan contexts have exited.
+       server teardown ONLY when SIGTERM is received (not on hot reload/SIGINT).
     4. Enhanced ``add_tool`` that accepts instances of
        :class:`hud.tools.base.BaseTool` which are classes that implement the
        FastMCP ``FunctionTool`` interface.
@@ -84,11 +96,17 @@ class MCPServer(FastMCP):
 
             @asynccontextmanager
             async def _lifespan(_: Any) -> AsyncGenerator[dict[str, Any], None]:
+                global _sigterm_received
                 try:
                     yield {}
                 finally:
-                    if self._shutdown_fn is not None:
+                    # Only call shutdown handler if SIGTERM was received
+                    if self._shutdown_fn is not None and _sigterm_received:
+                        logger.info("SIGTERM received, calling shutdown handler")
                         await self._shutdown_fn()
+                        _sigterm_received = False
+                    elif self._shutdown_fn is not None:
+                        logger.debug("Normal shutdown (hot reload), skipping shutdown handler")
 
             fastmcp_kwargs["lifespan"] = _lifespan
 
@@ -138,6 +156,18 @@ class MCPServer(FastMCP):
     # Shutdown decorator: runs after server stops
     # Supports dockerized SIGTERM handling
     def shutdown(self, fn: Callable | None = None) -> Callable | None:
+        """Register a shutdown handler that runs ONLY on SIGTERM.
+
+        This handler will be called when the server receives a SIGTERM signal
+        (e.g., during container shutdown). It will NOT be called on:
+        - SIGINT (Ctrl+C or hot reload)
+        - Normal client disconnects
+        - Other graceful shutdowns
+
+        This ensures that persistent resources (like browser sessions) are only
+        cleaned up during actual termination, not during development hot reloads.
+        """
+
         def decorator(func: Callable) -> Callable:
             self._shutdown_fn = func
             return func
